@@ -97,11 +97,8 @@ int main(int argc, char *argv[])
 
   try
   {
-    // TODO: Pass context to init as soon as that init() overload has been
-    // uncommented in cluttermm. This depends on a clutter release with
-    // clutter bug #1033 fixed.
     // initialize the C++ wrapper types
-    Clutter::init(&argc, &argv); //, context);
+    Clutter::init(&argc, &argv, context);
   }
   catch(const Glib::Exception& ex)
   {
